@@ -27,16 +27,20 @@ fi
 TmpFPCDir=$TmpDir/fpc
 FPCTGZ=$TmpDir/fpc.tgz
 if [ "x$Download" = "xyes" ]; then
-  echo "downloading fpc svn ..."
+  echo "downloading fpc git ..."
   rm -rf $TmpFPCDir
   mkdir -p $TmpDir
   cd $TmpDir
-  svn export http://svn.freepascal.org/svn/fpc/trunk $TmpFPCDir
+  git clone https://gitlab.com/freepascal.org/fpc/source.git $TmpFPCDir
+  rm -rf $TmpFPCDir/.git*
   cd -
 else
-  echo "extracting fpc from local svn ..."
+  echo "extracting fpc from local git ..."
   rm -rf $TmpFPCDir
-  svn export $SourceDir $TmpFPCDir
+  mkdir -p $TmpFPCDir
+  cp -a $SourceDir/.git $TmpFPCDir/
+  git -C $TmpFPCDir restore .
+  rm -rf $TmpFPCDir/.git*
 fi
 
 cd $TmpDir
